# Redefine cmake macro
#
%define cmake \
        %__cmake \\\
        -DCMAKE_VERBOSE_MAKEFILE=ON \\\
        -DCMAKE_INSTALL_PREFIX:PATH=%{_prefix} \\\
        -DCMAKE_INSTALL_LIBDIR:PATH=%{_libdir} \\\
        -DINCLUDE_INSTALL_DIR:PATH=%{_includedir} \\\
        -DLIB_INSTALL_DIR:PATH=%{_libdir} \\\
        -DSYSCONF_INSTALL_DIR:PATH=%{_sysconfdir} \\\
        -DSHARE_INSTALL_PREFIX:PATH=%{_datadir} \\\
%if "%{?_lib}" == "lib64" \
        %{?_cmake_lib_suffix64} \\\
%endif \
        %{?_cmake_skip_rpath} \\\
        -DBUILD_SHARED_LIBS:BOOL=ON
#
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")} 
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

%global proton_datadir %{_datadir}/proton-%{version}

Name:           qpid-proton
Version:        0.9
Release:        8%{?dist}
Group:          System Environment/Libraries 
Summary:        A high performance, lightweight messaging library

License:        ASL 2.0
URL:            http://qpid.apache.org/proton/
Source0:        qpid-proton-0.9.1-updated.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  gcc
BuildRequires:  cmake
BuildRequires:  swig
BuildRequires:  pkgconfig
BuildRequires:  doxygen
BuildRequires:  e2fsprogs-devel
BuildRequires:  openssl-devel
BuildRequires:  python-devel

Patch0:         proton.patch
 
%description
Proton is a high performance, lightweight messaging library. It can be used in
the widest range of messaging applications including brokers, client libraries,
routers, bridges, proxies, and more. Proton is based on the AMQP 1.0 messaging
standard. Using Proton it is trivial to integrate with the AMQP 1.0 ecosystem
from any platform, environment, or language.


%package -n qpid-proton-c
Group:     System Environment/Libraries
Summary:   C libraries for Qpid Proton

%description -n qpid-proton-c
%{summary}.

%files -n qpid-proton-c
%defattr(-,root,root,-)
%dir %{proton_datadir}
%doc %{proton_datadir}/LICENSE
%doc %{proton_datadir}/README.md
%doc %{proton_datadir}/TODO
%{_mandir}/man1/*
%{_bindir}/proton-dump
%{_libdir}/libqpid-proton.so.*
%{_libdir}/cmake/Proton/Proton*

%post -n qpid-proton-c -p /sbin/ldconfig


%postun -n qpid-proton-c -p /sbin/ldconfig


%package -n qpid-proton-c-devel
Group:     Development/System
Requires:  qpid-proton-c%{?_isa} = %{version}-%{release}
Summary:   Development libraries for writing messaging apps with Qpid Proton

%description -n qpid-proton-c-devel
%{summary}.


%files -n qpid-proton-c-devel
%defattr(-,root,root,-)
%{_includedir}/proton
%{_libdir}/libqpid-proton.so
%{_libdir}/pkgconfig/libqpid-proton.pc
%{_libdir}/cmake/Proton
%{_datadir}/proton-%{version}/examples
%exclude %{_datadir}/proton-%{version}/examples/perl
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/recv
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/recv-async
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/send
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/send-async
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/CMakeFiles
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/Makefile
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/cmake_install.cmake
%exclude %{_datadir}/proton-%{version}/examples/c/messenger/CTestTestfile.cmake

%package -n qpid-proton-c-devel-doc
Group:     Documentation
Summary:   Documentation for the C development libraries for Qpid Proton
#BuildArch: noarch

%description -n qpid-proton-c-devel-doc
%{summary}.

%files -n qpid-proton-c-devel-doc
%defattr(-,root,root,-)
%{proton_datadir}/docs/api-c



%package -n python-qpid-proton
Group:    System Environment/Libraries
Summary:  Python language bindings for the Qpid Proton messaging framework

Requires: qpid-proton-c%{?_isa} = %{version}-%{release}
Requires: python

%description -n python-qpid-proton
%{summary}.

%files -n python-qpid-proton
%defattr(-,root,root,-)
%{python_sitearch}/_cproton.so
%{python_sitearch}/cproton.*
%{python_sitearch}/proton/*


%package -n python-qpid-proton-doc
Group:   Documentation
Summary: Documentation for the Python language bindings for Qpid Proton
#BuildArch: noarch

%description -n python-qpid-proton-doc
%{summary}.

%files -n python-qpid-proton-doc
%defattr(-,root,root,-)
#%doc %{proton_datadir}/docs/api-py

%prep
%setup -q -n %{name}-%{version}

%patch0 -p1

%build
%cmake -DPROTON_DISABLE_RPATH=true -DCMAKE_BUILD_TYPE=RelWithDebInfo -DCMAKE_EXE_LINKER_FLAGS="-Wl,-z,relro,-z,now" -DCMAKE_SHARED_LINKER_FLAGS="-Wl,-z,relro" -DCMAKE_MODULE_LINKER_FLAGS="-Wl,-z,relro" -DCMAKE_INSTALL_PREFIX=/usr -DSYSINSTALL_BINDINGS=ON -DBUILD_RUBY=OFF 
make all docs %{?_smp_mflags}

%install
#%make_install 
make install DESTDIR=%{buildroot}

chmod +x %{buildroot}%{python_sitearch}/_cproton.so

# clean up files that are not shipped
rm -rf %{buildroot}%{_libdir}/perl5
rm -rf %{buildroot}%{_libdir}/php
rm -rf %{buildroot}%{_libdir}/java
rm -rf %{buildroot}%{_libdir}/libproton-jni.so
rm -rf %{buildroot}%{_libdir}/ruby
rm -rf %{buildroot}%{_datarootdir}/php
rm -rf %{buildroot}%{_datarootdir}/java
rm -rf %{buildroot}%{_datarootdir}/perl5
rm -rf %{buildroot}%{_datarootdir}/ruby
rm -rf %{buildroot}%{_sysconfdir}/php.d
rm -rf %{buildroot}%{_libdir}/proton.cmake

%changelog
* Wed Nov  4 2015 Irina Boverman <iboverma@redhat.com> - 0.9-8
- Added PROTON-1032 (bz1276366) fix, RHEL 5 only

* Tue Sep 29 2015 Irina Boverman <iboverma@redhat.com> - 0.9-7
- Added PROTON-1010 fix

* Thu Sep 24 2015 Irina Boverman <iboverma@redhat.com> - 0.9-6
- Added PROTON-1003 fix

* Thu Sep 10 2015 Irina Boverman <iboverma@redhat.com> - 0.9-5
- Added 0002-PROTON-972-allow-heartbeat-to-be-specified-for-Block.patch

* Wed Jun  3 2015 Irina Boverman <iboverma@redhat.com> - 0.9-4
- Added PROTON-858-fix-deletion-of-entries-from-map-to-.patch

* Thu May  7 2015 Irina Boverman <iboverma@redhat.com> - 0.9-3
- Rebased to 0.9.1 upstream

* Tue Mar 31 2015 Irina Boverman <iboverma@redhat.com> - 0.9-2
- Rebased to final 0.9 upstream

* Wed Mar 25 2015 Irina Boverman <iboverma@redhat.com> - 0.9-1.20150325
- Rebased to upstream snapshot at commit 810088b (last commit on 0.9 branch) 

* Wed Mar 25 2015 Irina Boverman <iboverma@redhat.com> - 0.9-1.20150223
- Rebased to upstream master branch 2015-02-23 snapshot

* Wed Jan 14 2015 Irina Boverman <iboverma@redhat.com> - 0.7-5
- Resolved: 1153769

* Thu Sep  4 2014 Irina Boverman <iboverma@redhat.com> - 0.7-4
- Resolved: 1126074

* Fri Aug  1 2014 Irina Boverman <iboverma@redhat.com> - 0.7-3
- Resolved: 1109320

* Thu May 29 2014 Irina Boverman <iboverma@redhat.com> - 0.7-2
- Add Visual-Studio-2008 patch

* Fri May  2 2014 Irina Boverman <iboverma@redhat.com> - 0.7-1 
- Rebase to 0.7
               
* Mon Feb 10 2014 Irina Boverman <iboverma@redhat.com> - 0.6-1
- Rebasing to 0.6-rc3

* Fri Nov 15 2013 Irina Boverman <iboverma@redhat.com> - 0.5-9
- Additional fixes for 1023639

* Wed Nov  6 2013 Irina Boverman <iboverma@redhat.com> - 0.5-8
- Resolved 1023639

* Thu Sep 26 2013 Irina Boverman <iboverma@redhat.com> - 0.5-6
- Added changes required to fix bz 995554 

* Mon Sep 23 2013 Irina Boverman <iboverma@redhat.com> - 0.5-5
- Changed spec file to remove additional items

* Thu Sep 19 2013 Irina Boverman <iboverma@redhat.com> - 0.5-4
- Changed python-qpid-proton-doc sub-package to noarch

* Tue Sep 17 2013 Irina Boverman <iboverma@redhat.com> - 0.5-3
- Added qpid-proton-c-devel-doc/noarch package to resolve bz 1005058 

* Wed Aug 28 2013 Irina Boverman <iboverma@redhat.com> - 0.5-2
- Built from mrg-messaging-3-rhel-6 branch

* Wed Aug 28 2013 Irina Boverman <iboverma@redhat.com> - 0.5-1
- Revised to Qpid Proton 0.5 version
- Resolves bz: 1002290

* Wed Apr 10 2013 Irina Boverman <iboverma@redhat.com> - 0.4-2.2
- Initial packaging of the Qpid Proton for a product.

* Fri Apr  4 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.4-2.2
- Added Obsoletes and Provides for packages whose names changed.
- Resolves: BZ#948784

* Mon Apr  1 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.4-2.1
- Fixed the dependencies for qpid-proton-devel and python-qpid-proton.

* Thu Mar 28 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.4-2
- Moved all C libraries to the new qpid-proton-c subpackage.

* Wed Mar 13 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.4-1
- Rebased on Proton 0.4.
- On EL6 BR pulls in Cmake 2.8 on PPC/PPC64.

* Thu Feb 21 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.3-4
- Fixes copying nested data.
- PROTON-246, PROTON-230

* Mon Jan 28 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.3-3
- Fixes build failure on non-x86 platforms.
- Resolves: BZ#901526

* Fri Jan 25 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.3-2
- Fixes build failure on non-x86 platforms.
- Resolves: BZ#901526

* Wed Jan 16 2013 Darryl L. Pierce <dpierce@redhat.com> - 0.3-1
- Rebased on Proton 0.3.

* Fri Dec 28 2012 Darryl L. Pierce <dpierce@redhat.com> - 0.2-2.4
- Moved ownership of the docs dir to the docs package.

* Wed Dec 19 2012 Darryl L. Pierce <dpierce@redhat.com> - 0.2-2.3
- Fixed package dependencies, adding the release macro.

* Mon Dec 17 2012 Darryl L. Pierce <dpierce@redhat.com> - 0.2-2.2
- Fixed subpackage dependencies on main package.
- Removed accidental ownership of /usr/include.

* Thu Dec 13 2012 Darryl L. Pierce <dpierce@redhat.com> - 0.2-2.1
- Remove BR for ruby-devel.
- Removed redundant package name from summary.
- Removed debugging artifacts from specfile.
- Moved unversioned library to the -devel package.
- Added dependency on main package to -devel. 
- Fixed directory ownerships.

* Fri Nov 30 2012 Darryl L. Pierce <dpierce@redhat.com> - 0.2-2
- Removed BR on help2man.
- Added patch for generated manpage.

* Mon Nov  5 2012 Darryl L. Pierce <dpierce@redhat.com> - 0.2-1
- Initial packaging of the Qpid Proton.
